require 'net/http'
require 'uri'

module Faye
  class Publisher

    class PublicationError < StandardError; end

    def initialize(faye_endpoint)
      @faye_uri = URI.parse(faye_endpoint)
    end

    # Sends an event to given chanel with the given data.
    #
    # @raise [PublicationError] if the publication fails.
    def publish(channel, data)
      http = Net::HTTP.new(@faye_uri.host, @faye_uri.port)

      path = if @faye_uri.path.empty?
               '/'
             else
               @faye_uri.path
             end
      headers = { 'Content-Type' => 'application/json' }
      message = { :channel => channel, :data => data }

      response, _ = http.post(path, JSON(message), headers)

      unless response.kind_of?(Net::HTTPSuccess)
        raise PublicationError
      end
    end

  end
end